/*
 * Sonar
 * Ultrahangos távolságmérő HC-SR04 szenzorral
 *
 * Hardver követelmények:
 *  - Arduino kártya ATmega328 MCU-val
 *  - HC-SR04 ultrahangos szenzor, az alábbi bekötéssel
 *
 *  HC-SR04        Arduino kártya
 * ----------------------------------------
 *  1. VCC            +5V
 *  2. Trigger        D7
 *  3. Echo           D8
 *  4. GND            GND
 *
 *
 * A program eredetijének forrása:
 * http://arduinobasics.blogspot.hu/2012/11/arduinobasics-hc-sr04-ultrasonic-sensor.html
 *
 */


#define echoPin 8          // Echo bemenet
#define trigPin 7          // Trigger kimenet
#define RED_LED 13         // LED  

int maximumRange = 400;    // Legnagyobb távolság cm-ben
int minimumRange = 1;      // Minimális távolság cm-ben
long duration;             // Időtartam [us]
float distance;            // Távolság [cm]

void setup() {
  Serial.begin (9600);
  Serial.println("Sonar program");
  pinMode(trigPin, OUTPUT);
  pinMode(echoPin, INPUT);
  digitalWrite(trigPin, LOW); 
  pinMode(RED_LED,OUTPUT);
  digitalWrite(RED_LED,HIGH);
}

void loop() {
  delay(1000);
  digitalWrite(RED_LED,HIGH);
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10); 
  digitalWrite(trigPin, LOW);
  duration = pulseIn(echoPin, HIGH);
  digitalWrite(RED_LED,LOW); 
  distance = duration/58.82; // Kiszámoljuk a távolságot
  if (distance >= maximumRange || distance < minimumRange) {
    distance = -1.0;
  }  
  Serial.print(distance);  // A mért távolság kiíratása
  Serial.println(" cm"); 
}
